import 'package:flutter/material.dart';
import 'package:lists_and_grids/bob_data.dart';

void main() {
  WidgetsFlutterBinding.ensureInitialized();
  runApp(const MaterialApp(title: "BobRoss", home: HomeScreen()));
}

class HomeScreen extends StatelessWidget {
  const HomeScreen({super.key});

  @override
  Widget build(BuildContext context) {
    BobRossData data = BobRossData();
    return Scaffold(
      appBar: AppBar(title: Text("Home")),
      body: Center(
        child: Column(
          mainAxisAlignment: MainAxisAlignment.center,
          children: [
            ElevatedButton(
              onPressed: () {},
              child: Text("Go to ListView Screen"),
            ),
            const SizedBox(height: 8),
            ElevatedButton(
              onPressed: () {},
              child: Text("Go to GridView Screen"),
            )
          ],
        ),
      ),
    );
  }
}

class ListScreen extends StatelessWidget {
  const ListScreen(this.paintingNames, {super.key});

  final List<String> paintingNames;

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: AppBar(title: const Text("ListView")),
      backgroundColor: Colors.grey[800],
      body: ListView.builder(
        padding: const EdgeInsets.all(16),
        itemBuilder: (context, index) {
          return Card(
            child: ListTile(
              onTap: () => print("You clicked on ${paintingNames[index]}"),
              leading: const Icon(Icons.brush),
              title: Text(paintingNames[index]),
              subtitle: const Text("Bob Ross"),
              trailing: const Icon(Icons.more_vert),
            ),
          );
          // return Container(
          //   decoration: BoxDecoration(border: Border.all(width: 3)),
          //   child: Text(
          //     bobRossPaintings[index],
          //     style: const TextStyle(fontSize: 32, color: Colors.teal),
          //   ),
          // );
        },
      ),
    );
  }
}

class GridScreen extends StatelessWidget {
  const GridScreen(this.paintings, {super.key});

  final List<BobRossPainting> paintings;

  @override
  Widget build(BuildContext context) {
    return Scaffold(
        appBar: AppBar(title: const Text("GridView")),
        backgroundColor: Colors.grey[800],
        body: GridView.builder(
          padding: const EdgeInsets.all(8),
          itemCount: paintings.length,
          gridDelegate: const SliverGridDelegateWithFixedCrossAxisCount(
            crossAxisCount: 2,
            mainAxisSpacing: 8,
            crossAxisSpacing: 16,
          ),
          itemBuilder: (context, index) => MyCard(painting: paintings[index]),
        ));
  }
}

class MyCard extends StatelessWidget {
  const MyCard({required this.painting, super.key});
  final BobRossPainting painting;

  @override
  Widget build(BuildContext context) {
    return Card(
      child: Padding(
        padding: const EdgeInsets.all(4),
        child: Column(
          crossAxisAlignment: CrossAxisAlignment.start,
          children: [
            Image.asset("assets/images/painting${painting.paintingId}.png"),
            Text(
              painting.title,
              style: TextStyle(
                color: Colors.grey[700],
                fontSize: 14,
                fontWeight: FontWeight.bold,
              ),
            ),
            Row(
              mainAxisAlignment: MainAxisAlignment.spaceBetween,
              children: [
                Text("S.${painting.season} Ep.${painting.episode}"),
                Text("Colors: ${painting.colorCount}")
              ],
            )
          ],
        ),
      ),
    );
  }
}
